# patina

[![Documentation Status](https://readthedocs.org/projects/patina/badge/?version=latest)](https://patina.readthedocs.io/en/latest/?badge=latest)

This is an implementation of Rust's Result and Option types in Python. Most
methods have been implemented, and the (very good) [original documentation] has
been adapted into docstrings.

The documentation for this package can be read [here][docs]. All doctests are
run and type-checked as part of the CI pipeline as unit tests. The tests are
direct ports of those in the Rust documentation.

[original documentation]: https://doc.rust-lang.org/std/result/
[docs]: https://result.readthedocs.io/en/latest